@@ -3,7 +3,7 @@ from .managers import BulkManager,chunks
 import re
 
 # Create your models here.
-from .utils import fetch_celex_resource
+from .helper import fetch_celex_resource
 
 
 class WordManager(BulkManager):
