@@ -1,19 +1,7 @@
-import os
-
-from django.conf import settings
 
 from .models import FreqDict,Word,Spelling,Transcription
 
 
-def fetch_celex_resource(uri):
-    path = os.path.join(settings.CELEX_ROOT,uri)
-    return path
-
-def fetch_media_resource(uri):
-    path = os.path.join(settings.MEDIA_ROOT,uri)
-    return path
-
-
 def checkDict(freqDict):
     if FreqDict.objects.filter(Name=freqDict).exists():
         return True
